/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.ddms;

import com.google.gson.Gson;
import org.opengroup.osdu.register.model.Ddms;
import org.opengroup.osdu.register.util.CreateApiTestTemplate;
import org.opengroup.osdu.register.util.RestDescriptor;
import com.sun.jersey.api.client.ClientResponse;

import static org.junit.Assert.*;

public abstract class CreateRegistrationApiTest extends CreateApiTestTemplate {

    public CreateRegistrationApiTest() {
        super(new DeleteDdmsDescriptor(), new CreateDdmsDescriptor());
    }

    @Override
    protected boolean isDataInTenant() {
        return true;
    }

    @Override
    protected void validate20XResponse(ClientResponse response, RestDescriptor descriptor) {
        String body = response.getEntity(String.class);
        Ddms ddms = new Gson().fromJson(body, Ddms.class);
        assertEquals(getId(), ddms.id);
        assertEquals("My test ddms.", ddms.description);
        assertTrue(ddms.contactEmail, ddms.contactEmail.equals("test@test.com"));
        assertNotNull(ddms.createdDateTimeEpoch);
        assertEquals("logDDMS", ddms.name);
        assertEquals(1, ddms.interfaces.size());
        assertEquals("wellbore", ddms.interfaces.iterator().next().entityType);
    }
}
